# Frequenz Weather API Client Release Notes

## Summary

<!-- Here goes a general summary of what this release is about -->

## Upgrading

<!-- Here goes notes on how to upgrade from previous versions, including deprecations and what they should be replaced with -->

## New Features

* Add the client and cli from[frequenz-api-weather v0.11.1](https://github.com/frequenz-floss/frequenz-api-weather/releases/tag/v0.11.1).
* Add support for the live RPC to the cli tool.
<!-- Here goes the main new features and examples or instructions on how to use them -->

## Bug Fixes

<!-- Here goes notable bug fixes that are worth a special mention or explanation -->
